@@ -1,4 +1,8 @@
-from .exceptions import MetaloaderError, ExclusiveStanzaClashError
+from .exceptions import (
+    MetaloaderError,
+    ExclusiveStanzaClashError,
+    StanzaValidationError
+)
 from .filesystems import Filesystem, LocalFilesystem, VirtualFilesystem
 from .serialisations import Serialisation, JsonSerialisation, YamlSerialisation
 from .stanzahandlers import StanzaHandler, ListStanzaHandler, DictStanzaHandler
@@ -8,6 +12,7 @@ from .flat_loader import FlatLoader
 __all__ = [
     "MetaloaderError",
     "ExclusiveStanzaClashError",
+    "StanzaValidationError",
     "Filesystem",
     "LocalFilesystem",
     "VirtualFilesystem",
